Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1045)

Unified Diff: src/parsing/parser-base.h

Issue 2235423003: [parser] improve inferred function names for async arrow functions (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: really the last of it Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/parsing/parser-base.h
diff --git a/src/parsing/parser-base.h b/src/parsing/parser-base.h
index c7e4daf97c2b555056c1e17d9d7d78d09df19f0f..33975e86c661c734128ff4f9348b048028619810 100644
--- a/src/parsing/parser-base.h
+++ b/src/parsing/parser-base.h
@@ -2322,11 +2322,17 @@ ParserBase<Traits>::ParseAssignmentExpression(bool accept_IN,
}
if (is_async && peek_any_identifier() && PeekAhead() == Token::ARROW) {
- // async Identifier => AsyncConciseBody
- IdentifierT name =
- ParseAndClassifyIdentifier(&arrow_formals_classifier, CHECK_OK);
- expression = this->ExpressionFromIdentifier(name, position(),
- scanner()->location().end_pos);
+ if (this->IsIdentifier(expression)) {
+ // async Identifier => AsyncConciseBody
+ IdentifierT name =
+ ParseAndClassifyIdentifier(&arrow_formals_classifier, CHECK_OK);
+ expression = this->ExpressionFromIdentifier(
+ name, position(), scanner()->location().end_pos, InferName::No);
+ if (fni_) {
+ // Remove `async` keyword from inferred name stack.
+ fni_->RemoveAsyncKeywordFromEnd();
+ }
+ }
}
if (peek() == Token::ARROW) {
@@ -2882,10 +2888,13 @@ ParserBase<Traits>::ParseLeftHandSideExpression(
}
Scanner::Location spread_pos;
typename Traits::Type::ExpressionList args;
- if (V8_UNLIKELY(is_async)) {
+ if (V8_UNLIKELY(is_async && this->IsIdentifier(result))) {
ExpressionClassifier async_classifier(this);
args = ParseArguments(&spread_pos, true, &async_classifier, CHECK_OK);
if (peek() == Token::ARROW) {
+ if (fni_) {
+ fni_->RemoveAsyncKeywordFromEnd();
+ }
ValidateBindingPattern(&async_classifier, CHECK_OK);
if (!async_classifier.is_valid_async_arrow_formal_parameters()) {
ReportClassifierError(
« src/parsing/parser.cc ('K') | « src/parsing/parser.cc ('k') | src/parsing/preparser.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698